@@ -4,14 +4,17 @@
 #  All rights reserved
 
 from . import dates
+from . import exceptions
 from . import sensoria_io_client
 from . import tools
 
 from .dates import *  # NOQA
+from .exceptions import *  # NOQA
 from .sensoria_io_client import *  # NOQA
 from .tools import *  # NOQA
 
 __all__ = []
 __all__ += dates.__all__
+__all__ += exceptions.__all__
 __all__ += tools.__all__
 __all__ += sensoria_io_client.__all__
