@@ -4,6 +4,9 @@
 #  All rights reserved
 
 
+__all__ = ['FitError', 'MaximumDepthError', 'InvalidSessionError']
+
+
 class FitError(Exception):
     def __init__(self, *args):
         super().__init__(*args)
@@ -12,3 +15,8 @@ class FitError(Exception):
 class MaximumDepthError(Exception):
     def __init__(self, *args):
         super().__init__(*args)
+
+
+class InvalidSessionError(Exception):
+    def __init__(self, *args):
+        super().__init__(*args)
